package com.example.nto.controller;

import com.example.nto.entity.Employee;
import com.example.nto.entity.Visits;
import com.example.nto.exception.EmployeeIsAdminException;
import com.example.nto.exception.EmployeeNotFoundException;
import com.example.nto.exception.VisitsEmptyException;
import com.example.nto.service.EmployeeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Optional;

@RestController
@RequestMapping("/api/admin")
public class AdminController {
    @Autowired
    private EmployeeService employeeService;

    @GetMapping("/employees")
    public List<Employee> getEmployees() {
        return employeeService.getAllEmployees();
    }

    @GetMapping("/{username}/info")
    public ResponseEntity<?> getEmployeeInfo(@PathVariable("username") String username) {
        Optional<Employee> employee = employeeService.findByLogin(username);
        if (employee.isEmpty()) {
            throw new EmployeeNotFoundException();
        }

        return new ResponseEntity<>(employee.get(), HttpStatus.OK);
    }

    @GetMapping("/{username}/lastVisit")
    public ResponseEntity<?> getEmployeeLastVisit(@PathVariable("username") String username) {
        Optional<Employee> employee = employeeService.findByLogin(username);
        if (employee.isEmpty()) {
            throw new EmployeeNotFoundException();
        }

        return new ResponseEntity<>(employee.get().getLastVisit(), HttpStatus.OK);
    }

    @GetMapping("/{username}/visits")
    public ResponseEntity<?> getEmployeeVisits(@PathVariable("username") String username) {
        if (!employeeService.existsByLogin(username)) {
            throw new EmployeeNotFoundException();
        }

        Optional<List<Visits>> visits = Optional.ofNullable(employeeService.getEmployeeVisits(username));

        if (visits.isEmpty()) {
            throw new VisitsEmptyException();
        }

        return new ResponseEntity<>(visits.get(), HttpStatus.OK);
    }

    @PostMapping("/{username}/block")
    public ResponseEntity<?> blockEmployee(@PathVariable("username") String username) {
        Optional<Employee> employee = employeeService.findByLogin(username);
        if (employee.isEmpty()) {
            throw new EmployeeNotFoundException();
        }



        employeeService.block(employee.get().getId());

        String prefix = "B";
        if (employee.get().getBlocked()) {
            prefix = "Unb";
        }

        return new ResponseEntity<>("Employee" + prefix + "lockedSuccess", HttpStatus.OK);
    }
}
